@@ -295,9 +295,21 @@ class Dataset(FolderHierarchyBase):
     def run(self, wait:bool=False, interval:float=1.0) -> None:
         """Launch the tool which has been configured for this dataset."""
 
+        # If a launcher has been set up
+        if self.index.get("launcher") is not None:
+
+            # Then the dataset will start by running the launcher
+            entrypoint = "launcher"
+
+        # Otherwise, if a launcher has not been set up
+        else:
+
+            # Then the dataset will start by running the tool directly
+            entrypoint = "tool"
+
         # Start the process
         proc = subprocess.Popen(
-            ["/bin/bash", self.wb_path("helpers/run_launcher")],
+            ["/bin/bash", self.wb_path(f"helpers/run_{entrypoint}")],
             start_new_session=True,
             cwd=self.base_path
         )
@@ -404,3 +416,14 @@ class Dataset(FolderHierarchyBase):
             cwd=self.base_path
         )
 
+    def remove_asset(self, asset_type) -> None:
+        """Clear an asset type from the dataset index."""
+
+        # If the asset is defined
+        if self.index.get(asset_type) is not None:
+
+            # Remove it from the index
+            del self.index[asset_type]
+
+            # And save the index
+            self.write_index(overwrite=True)
